//******************************************************************************
//******************************************************************************
//*   Copyright (C) 2018 K. Vasudevan. Indian Institute of Technology Kanpur.
//*   All Rights Reserved.
//******************************************************************************
// Constants.
//******************************************************************************
SNR_DB=[0:0.5:4];                                          // SNR per bit in dB.
PRE_AMB_SIZE=512;                                    // Length of the preamble.
OFDM_SIZE=1024;           // Length of OFDM symbol, excluding the cyclic prefix.
CHAN_MEM=9;                                         // Length of channel memory.
CHAN_LEN=CHAN_MEM+1;                                       // Length of channel.
EST_CHAN_MEM=2*CHAN_MEM;                     // Estimated memory of the channel.
EST_CHAN_LEN=EST_CHAN_MEM+1;                        // Estimated channel length.
FRAME_SIZE=OFDM_SIZE+EST_CHAN_MEM;        // Frame size including cyclic prefix.
RX_DATA_SIZE=FRAME_SIZE+CHAN_LEN-1;                       // Length of rx. data.
NUM_TX=4;                                           // No. of transmit antennas.
NUM_RX=NUM_TX;                                       // No. of receive antennas.
NUM_RE_TX=2;                                          // No. of retransmissions.
PRE_AMB_QPSK_AMP=sqrt(4*PRE_AMB_SIZE/OFDM_SIZE);                  // Preamb amp.
//******************************************************************************
if NUM_TX > 8 then
 mprintf('No. of transmitters must not exceed 8.\n');
 quit;
elseif NUM_TX < 4 then
 mprintf('No. of transmitters must greater than or equal to 4.\n');
 quit;
end
//******************************************************************************
// Open files for appending.
//******************************************************************************
//format(20);
//y1=string(PRE_AMB_SIZE);
//y2=string(NUM_TX);
//y3=string(NUM_RE_TX);
//y5=string(OFDM_SIZE);
//fd_f_eer_th_w =mopen(pwd()+'/f_eer_th_'+'_Lp'+y1+'_Nt'+y2+'_Re'+...
//            y3+'_Ld'+y5+'.txt','at');
//clear x y y1 y2 y3 y5;
//******************************************************************************
// SNR parameters.
//******************************************************************************
FADE_VAR=0.5;                               // Variance per dimension of fading.
//******************************************************************************
// Variance per dimension of AWGN. Set noise variance and frequency offset
// equal to zero for testing.
//******************************************************************************
NOISE_VAR=2.0*NUM_TX*NUM_RE_TX*CHAN_LEN./(OFDM_SIZE*10^(0.1*SNR_DB));
//******************************************************************************
Es=2*PRE_AMB_QPSK_AMP*PRE_AMB_QPSK_AMP;
Z_Var=FADE_VAR+NOISE_VAR/Es;                 // Variance per dim of signal part.
Y_Var=NOISE_VAR/Es;                           // Variance per dim of noise part.
//P0=Z_Var./(Y_Var+Z_Var);
//P_No_Erasure=P0.^(NUM_TX*NUM_RX*NUM_RE_TX);
//P_Erasure=1-P_No_Erasure;
//******************************************************************************
// Get the terms in the summation.
//******************************************************************************
for i=0:CHAN_MEM 
 Terms(i+1,:)=(-1)^i*(factorial(9)/(factorial(i)*factorial(9-i)))* ...
              Y_Var./((i+1)*Y_Var+Z_Var);
end
//******************************************************************************
P_Erasure=sum(Terms,'r');                                      // For one frame.
P_No_Erasure=(1-P_Erasure).^(NUM_TX*NUM_RX*NUM_RE_TX);         // For all re-tx.
P_Erasure_All=1-P_No_Erasure;                                  // For all re-tx.
//******************************************************************************
